@@ -24,7 +24,7 @@
 This file implement the hardening audit of the WebScripts installation and
 configuration."""
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -72,6 +72,13 @@ import stat
 import sys
 import os
 
+try:
+    import pip._internal.operations.freeze
+except ImportError:
+    PIP = False
+else:
+    PIP = True
+
 ServerConfiguration = TypeVar("ServerConfiguration")
 Server = TypeVar("Server")
 Logs = TypeVar("Logs")
@@ -696,6 +703,44 @@ class Audit:
 
         venv_modules = []
 
+        if PIP and Audit.is_windows:
+            modules = [
+                package
+                for package in pip._internal.operations.freeze.freeze()
+                if not package.startswith("pip==")
+                and not package.startswith("setuptools==")
+                and not package.startswith("pywin32==")
+                and not package.startswith("WebScripts==")
+            ]
+            return Rule(
+                "Virtualenv modules",
+                32,
+                len(modules) == 0,
+                3,
+                SEVERITY.LOW.value,
+                "Installation",
+                "WebScripts should be install in empty virtualenv (except "
+                f"pywin32 on Windows), modules found: {modules}.",
+            )
+        elif PIP and not Audit.is_windows:
+            modules = [
+                package
+                for package in pip._internal.operations.freeze.freeze()
+                if not package.startswith("pip==")
+                and not package.startswith("setuptools==")
+                and not package.startswith("WebScripts==")
+            ]
+            return Rule(
+                "Virtualenv modules",
+                32,
+                len(modules) == 0,
+                3,
+                SEVERITY.LOW.value,
+                "Installation",
+                "WebScripts should be install in empty virtualenv (except "
+                f"pywin32 on Windows), modules found: {modules}.",
+            )
+
         if Audit.is_windows:
             preinstall_modules = [
                 "WebScripts-script",
@@ -1443,6 +1488,26 @@ class Audit:
             sleep(3600)
 
 
+'''class FilesIntegity:
+
+    """This class check the files integrity."""
+
+    def __init__(self):
+        self.
+
+    def check_files_integrity(self):
+
+        """"""
+
+        with open("default_files.json") as file:
+            files = json.load(file)
+
+        for directory in ():
+            for file, data in files:
+                ...
+'''
+
+
 def main(server: Server, logs: Logs, send_mail: Callable) -> Report:
 
     """Main function to execute this file."""
