@@ -59,55 +59,65 @@ def import_without_package():
     # CHANGE CONTEXT AND SYS
     ########################
 
-    for i in [0, 0, -1, -1]:
-        sys.path.pop(i)
+    error = None
 
-    rename(dst1, dst2)
-    chdir(path.join(dir_path, "..", "WebScripts"))
-    sys.path.insert(0, "")
+    try:
+        for i in [0, 0, -1, -1]:
+            sys.path.pop(i)
 
-    for name in [
-        "WebScripts",
-        "Configuration",
-        "Server",
-        "WebScriptsConfigurationTypeError",
-        "commons",
-        "Blacklist",
-        "Session",
-    ]:
-        if name in locals().keys():
-            del locals()[name]
-        if name in globals().keys():
-            del globals()[name]
+        rename(dst1, dst2)
+        chdir(path.join(dir_path, "..", "WebScripts"))
+        sys.path.insert(0, "")
 
-    remove_names = []
-    for name in sys.modules.keys():
-        if "WebScripts." in name or name == "WebScripts":
-            remove_names.append(name)
+        for name in [
+            "WebScripts",
+            "Configuration",
+            "Server",
+            "WebScriptsConfigurationTypeError",
+            "commons",
+            "Blacklist",
+            "Session",
+        ]:
+            if name in locals().keys():
+                del locals()[name]
+            if name in globals().keys():
+                del globals()[name]
 
-    for name in remove_names:
-        del sys.modules[name]
+        remove_names = []
+        for name in sys.modules.keys():
+            if "WebScripts." in name or name == "WebScripts":
+                remove_names.append(name)
 
-    from WebScripts import (
-        Configuration,
-        Server,
-        WebScriptsConfigurationTypeError,
-    )
-    from commons import Blacklist, Session
+        for name in remove_names:
+            del sys.modules[name]
+
+        from WebScripts import (
+            Configuration,
+            Server,
+            WebScriptsConfigurationTypeError,
+        )
+        from commons import Blacklist, Session
+
+    except Exception as e:
+        error = e
 
     #########################
     # REBUILD CONTEXT AND SYS
     #########################
-    sys.path = path_
-    sys.modules = modules
-    rename(dst2, dst1)
-    chdir(current_path)
+    finally:
+        sys.path = path_
+        sys.modules = modules
+        rename(dst2, dst1)
+        chdir(current_path)
 
-    for name, value in locals_.items():
-        locals()[name] = value
+        for name, value in locals_.items():
+            locals()[name] = value
 
-    for name, value in globals_.items():
-        globals()[name] = value
+        for name, value in globals_.items():
+            globals()[name] = value
+
+    if error:
+        raise error
 
 
 disable_logs()
@@ -467,6 +477,20 @@ class TestServer(TestCase):
         self.assertIn("/test/...", urls)
 
     def test_get_attributes(self):
+        class CodeTest:
+            def __init__(self):
+                pass
+
+            def methodTest1(self):
+                pass
+
+            def methodTest2(self, a, b, c, d, e, f, g):
+                pass
+
+            @staticmethod
+            def methodTest3(a, b, c, d, e, f, g):
+                pass
+
         object_ = Mock(a=Mock(b=object))
         callable_, filename, bool_ = self.server.get_attributes(
             object_, ["a", "b", "test"], True
@@ -476,6 +500,31 @@ class TestServer(TestCase):
         self.assertIs(callable_, object)
         self.assertEqual(filename, "test")
 
+        object_ = CodeTest()
+        callable_, filename, bool_ = self.server.get_attributes(
+            object_, ["methodTest2", "test"], False
+        )
+
+        self.assertFalse(bool_)
+        self.assertEqual(callable_.__name__, object_.methodTest2.__name__)
+        self.assertEqual(filename, "test")
+
+        callable_, filename, bool_ = self.server.get_attributes(
+            object_, ["methodTest3", "test"], False
+        )
+
+        self.assertFalse(bool_)
+        self.assertEqual(callable_.__name__, object_.methodTest3.__name__)
+        self.assertEqual(filename, "test")
+
+        callable_, filename, bool_ = self.server.get_attributes(
+            object_, ["methodTest1", "test"], True
+        )
+
+        self.assertTrue(bool_)
+        self.assertIsNone(callable_)
+        self.assertIsNone(filename)
+
         callable_, filename, bool_ = self.server.get_attributes(
             "test", ["test"], False
         )
